@@ -1,6 +1,6 @@
 /*
   SPDX-FileCopyrightText: 2000 Hans Dijkema <kmailcvt@hum.org>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,6 +9,7 @@
 
 #include "mailimporter_export.h"
 #include <QString>
+#include <memory>
 class QWidget;
 namespace MailImporter
 {
@@ -43,8 +44,8 @@ public:
     Q_REQUIRED_RESULT bool removeDupMessage() const;
 
 private:
-    class Private;
-    Private *const d;
+    class FilterInfoPrivate;
+    std::unique_ptr<FilterInfoPrivate> const d;
 };
 }
 
